Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/server.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/build
diff options
context:
space:
mode:
authorJoas Schilling <coding@schilljs.com>2021-06-24 14:12:52 +0300
committerJoas Schilling <coding@schilljs.com>2021-06-24 14:12:52 +0300
commit99b7b82d72a6b0b69859ab8256d20dd819b716ef (patch)
treedf3dc5fa3ee01384f4965a1a30989cd6fdc945ee /build
parent4e9727037220a8acddf7a3478a047c0bc6fc4bae (diff)
Fix branch selection in stable22
Signed-off-by: Joas Schilling <coding@schilljs.com>
Diffstat (limited to 'build')
-rwxr-xr-xbuild/update-apps.sh8
-rwxr-xr-xbuild/update.sh6
2 files changed, 7 insertions, 7 deletions
diff --git a/build/update-apps.sh b/build/update-apps.sh
index e4611a79aff..57ee6dd5e08 100755
--- a/build/update-apps.sh
+++ b/build/update-apps.sh
@@ -1,14 +1,14 @@
#!/bin/bash
# Update Nextcloud apps from latest git master
# For local development environment
# Use from Nextcloud server folder with `./build/update-apps.sh`
#
# It automatically:
# - goes through all apps which are not shipped via server
# - shows the app name in bold and uses whitespace for separation
# - changes to master and pulls quietly
# - shows the 3 most recent commits for context
# - removes branches merged into master
# - … could even do the build steps if they are consistent for the apps (like `make`)
-find apps* -maxdepth 2 -name .git -exec sh -c 'cd {}/../ && printf "\n\033[1m${PWD##*/}\033[0m\n" && git checkout master && git pull --quiet -p && git --no-pager log -3 --pretty=format:"%h %Cblue%ar%x09%an %Creset%s" && printf "\n" && git branch --merged master | grep -v "master$" | xargs git branch -d && cd ..' \;
+find apps* -maxdepth 2 -name .git -exec sh -c 'cd {}/../ && printf "\n\033[1m${PWD##*/}\033[0m\n" && git checkout stable22 && git pull --quiet -p && git --no-pager log -3 --pretty=format:"%h %Cblue%ar%x09%an %Creset%s" && printf "\n" && git branch --merged stable22 | grep -v "stable22$" | xargs git branch -d && cd ..' \;
@@ -1,14 +1,14 @@
#!/bin/bash
-# Update Nextcloud apps from latest git master
+# Update Nextcloud apps from latest git stable22
# For local development environment
# Use from Nextcloud server folder with `./build/update-apps.sh`
@@ -1,14 +1,14 @@
# - goes through all apps which are not shipped via server
# - shows the app name in bold and uses whitespace for separation
-# - changes to master and pulls quietly
+# - changes to stable22 and pulls quietly
# - shows the 3 most recent commits for context
@@ -1,14 +1,14 @@
# - shows the 3 most recent commits for context
-# - removes branches merged into master
+# - removes branches merged into stable22
# - … could even do the build steps if they are consistent for the apps (like `make`)
diff --git a/build/update.sh b/build/update.sh
index 3a3d2eac5dc..1e8552ae296 100755
--- a/build/update.sh
+++ b/build/update.sh
@@ -1,15 +1,15 @@
#!/bin/bash
# Update Nextcloud server and apps from latest git master
# For local development environment
# Use from Nextcloud server folder with `./build/update.sh`
# Update server
printf "\n\033[1m${PWD##*/}\033[0m\n"
-git checkout master
+git checkout stable22
git pull --quiet -p
git --no-pager log -3 --pretty=format:"%h %Cblue%ar%x09%an %Creset%s"
printf "\n"
-git branch --merged master | grep -v "master$" | xargs git branch -d
+git branch --merged stable22 | grep -v "stable22$" | xargs git branch -d
git submodule update --init
# Update apps
@@ -1,15 +1,15 @@
#!/bin/bash
-# Update Nextcloud server and apps from latest git master
+# Update Nextcloud server and apps from latest git stable22
# For local development environment
# Use from Nextcloud server folder with `./build/update.sh`